History
*******

v0.1.1 (09-04-2018)
===================

- Open sourcing the project

v0.1.2 (15-04-2018)
===================

- Mostly documentation and dev setup patches
- Fix failing test on travis
